@@ -17,21 +17,21 @@ my %opt;
 GetOptions(\%opt,
     'all',
     'delete',
-    'delete-days:i',
+    'delete-days=i',
     'close',
-    'close-days:i',
+    'close-days=i',
     'bloom',
     'replicas',
     'replicas',
-    'replicas-min|replica-min:i',
-    'replicas-max|replica-max:i',
-    'replicas-age|replica-age:i',
+    'replicas-min|replica-min=i',
+    'replicas-max|replica-max=i',
+    'replicas-age|replica-age=i',
     'optimize',
-    'optimize-days:i',
-    'index-basename:s',
-    'date-separator:s',
-    'timezone:s',
-    'allocation-exclude:s%',
+    'optimize-days=i',
+    'index-basename=s',
+    'date-separator=s',
+    'timezone=s',
+    'allocation-exclude=s%',
     # Basic options
     'help|h',
     'manual|m',
@@ -224,7 +224,7 @@ es-daily-index-maintenance.pl - Run to prune old indexes and optimize existing
 
 =head1 VERSION
 
-version 5.6
+version 5.7
 
 =head1 SYNOPSIS
 
